Learn R Programming

sisal (version 0.48)

print.sisal: Printing Sequential Input Selection Objects

Description

Prints information contained in a sequential input selection object.

Usage

# S3 method for sisal
print(x, max.warn = 10, …)

Arguments

x

an object of class "sisal".

max.warn

a numeric value giving the maximum number of warnings to show. See max.warn in sisal.

additional arguments passed to other print methods.

Value

Invisibly returns x.

Details

The following information is printed:

  • Parameter values used in the sisal call

  • Data dimensions

  • Names of the input variables, if available

  • Selected inputs, L.v (smallest validation error)

  • Selected inputs, L.f (result within error margin)

  • Whether L.f is a subset of L.v (nested model) or not

  • The removal order and / or rank of the input variables (see plotSelected.sisal)

  • The stages of search (if any) at which branching reduced validation error compared to a hbranches = 1 solution. Not printed if branching was not used or if it is possible that the search did not proceed through every set of variables on the hbranches = 1 path, i.e. if pruning.keep.best was FALSE. One must note that these results, like many others, are subject to randomness. Thus the results may differ between successive runs of sisal.

  • Any warnings produced by the sisal run (see max.warn)

See Also

More information can be obtained with summary.sisal.

Examples

Run this code
# NOT RUN {
foo <- testSisal(dataset="toy", nData = 200, Mtimes = 10,
                 noiseSd = 0.5, verbose = 0)
print(foo)
# }

Run the code above in your browser using DataLab