summary method for class "sisal"
# S3 method for sisal
summary(object, …)
# S3 method for summary.sisal
print(x, …)an object of class "sisal".
an object of class "summary.sisal".
arguments passed to/from other methods.
The function summary.sisal returns a list with
class "summary.sisal", currently containing:
summary of the full model. An object of class
"summary.lm".
summary of the L.v model. An object of
class "summary.lm".
summary of the L.f model. An object of
class "summary.lm".
a data.frame containing information on the
best variable sets with a given number of variables, with the
following columns (copied from object):
number of inputs (row label).
mean training MSE.
standard deviation of training MSE.
mean validation MSE.
logical vector where the location
of TRUE points the smallest variable set with
thr.flag TRUE.
logical vector where the location
of TRUE points the variable set with the smallest
validation error.
logical vector where TRUE means
that error is at most E.v[L.v.flag] +
s.tr[L.v.flag].
The function print.summary.sisal invisibly returns x.
The functions compute and print summaries (summary.lm)
of the ordinary least squares regression models stored in the
object and some additional information.
# NOT RUN {
foo <- testSisal(dataset="toy", Mtimes=10, hbranches=2)
summary(foo)
# }
Run the code above in your browser using DataLab