Whether L.f is a subset of L.v (nested model) or
not
The removal order and / or rank of the input variables (see
plotSelected.sisal)
The stages of search (if any) at which branching reduced
validation error compared to a hbranches = 1 solution. Not
printed if branching was not used or if it is possible that the
search did not proceed through every set of variables on the
hbranches = 1 path, i.e. if pruning.keep.best was
FALSE. One must note that these results, like many others,
are subject to randomness. Thus the results may differ between
successive runs of sisal.
Any warnings produced by the sisal run (see
max.warn)
See Also
More information can be obtained with summary.sisal.