powered by
Numeric matrix with independent and dependent variables and noise
toy.test
The format is:
num [1:500, 1:12] -0.543 -0.881 0.115 0.461 -0.173 ... - attr(*, "dimnames")=List of 2 ..$ : NULL ..$ : chr [1:12] "y" "noise" "X1" "X2" ...
This is the test set of the toy data, i.e. 500 rows of the whole 1500 row dataset.
For other details, see toy.learn.
toy.learn
toy.learn, bootMSE
bootMSE
# NOT RUN { library(graphics) plot(as.data.frame(toy.test)) # }
Run the code above in your browser using DataLab